# Hi mineguys  👋


## 🛠️ Install     
```bash
pip install aternos
```

## 🧑🏻‍💻 Usage
```js
aternos start
aternos stop
aternos info
```

## Contributing

If you want participate project
```bash
poetry install
```

Depot coming soon
if you don't have [poetry](https://python-poetry.org/docs/#installation)
        